@@ -134,13 +134,13 @@ def orientation(contour: Contour) -> Orientation:
                 key=contour.__getitem__)
     previous_index, next_index = (index - 1 if index else len(contour) - 1,
                                   (index + 1) % len(contour))
-    while True:
+    for _ in range(len(contour)):
         candidate = angle_orientation(contour[index], contour[previous_index],
                                       contour[next_index])
-        if candidate is Orientation.COLLINEAR:
-            index, next_index = next_index, (next_index + 1) % len(contour)
-        else:
+        if candidate is not Orientation.COLLINEAR:
             return candidate
+        index, next_index = next_index, (next_index + 1) % len(contour)
+    return Orientation.COLLINEAR
 
 
 def _split(contour: Contour,
